@@ -25,7 +25,8 @@ def load_pickled_list( local_root_directory= '../data/', list_pkl_file_name = 'm
         my_list = pickle.load(f)
     return my_list
 
-def fetch_crypto_daily_data(ssj=None, pickle_saving_path=None, refetch_all=True, daily_crypto_starting_day ='2012-01-01'):
+def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix=None, refetch_all=True,daily_crypto_starting_day='2012-01-01'):
+    pickle_saving_path = local_root_directory+ssj+daily_return_pkl_filename_suffix
     if refetch_all:
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
@@ -419,112 +420,6 @@ def fetch_crypto_tuple_hourly_data(ssj=None, pickle_saving_path=None, refetch_al
         dataframe = pd.read_pickle(pickle_saving_path)
     return dataframe
 
-def fetch_crypto_daily_data(ssj=None, pickle_saving_path=None, refetch_all=True):
-    if refetch_all:
-        year = datetime.datetime.now().year
-        month = datetime.datetime.now().month
-        day = datetime.datetime.now().day
-        hour = datetime.datetime.utcnow().hour
-        ts = datetime.datetime(year, month, day, tzinfo=datetime.timezone.utc).timestamp() + hour * 3600
-        ts1 = ts - 2001 * 3600*24
-        ts2 = ts1 - 2001 * 3600*24
-        ts3 = ts2 - 2001 * 3600*24
-        ts4 = ts3 - 2001 * 3600*24
-        ts5 = ts4 - 2001 * 3600*24
-        ts6 = ts5 - 2001 * 3600*24
-        ts7 = ts6 - 2001 * 3600*24
-        ts8 = ts7 - 2001 * 3600*24
-        ts9 = ts8 - 2001 * 3600*24
-        ts10 = ts9 - 2001 * 3600*24
-        ts11 = ts10 - 2001 * 3600*24
-        ts12 = ts11 - 2001 * 3600*24
-        ts13 = ts12 - 2001 * 3600*24
-        print('Loading data')
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts13))
-        dataframe = pd.DataFrame(json.loads(r.text)['Data'])
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts12))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts11))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts10))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts9))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts8))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts7))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts6))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        print('waiting')
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts5))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        time.sleep(1)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts4))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts3))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts2))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts1))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-        r = requests.get(
-            'https://min-api.cryptocompare.com/data/histoday?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts))
-        df = pd.DataFrame(json.loads(r.text)['Data'])
-        dataframe = dataframe.append(df, ignore_index=True)
-
-        dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
-        dataframe = dataframe.sort_values(by=['time'])
-        dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
-        dataframe = dataframe.set_index(dataframe['date'])
-        dataframe = dataframe.drop(columns=['date'])
-        print('size fetched')
-        print(dataframe.shape)
-        dataframe.to_pickle(pickle_saving_path)
-    else:
-        dataframe = pd.read_pickle(pickle_saving_path)
-    return dataframe
-
 
 
 class NaPoleonXConnector(object):
